@@ -9,7 +9,7 @@ from django.conf import settings
 from decorator import commit_on_success
 
 __all__ = ('record', 'error_record', 'Journal')
-__version__ = '1.19.0'
+__version__ = '1.20.0'
 
 def unicode_truncate(s, length, encoding='utf-8'):
     '''Truncate an unicode string so that its UTF-8 encoding is less than
@@ -39,8 +39,10 @@ def record(tag, template, using=None, **kwargs):
                 'Missing variable for the template message', template, e)
     try:
         logger = logging.getLogger('django.journal.%s' % tag)
-        if tag.name == 'error':
+        if tag.name == 'error' or tag.name.startswith('error-'):
             logger.error(message)
+        elif tag.name == 'warning' or tag.name.startswith('warning-'):
+            logger.warning(message)
         else:
             logger.info(message)
     except:
